
#include <iostream>

#include "TSystem.h"
#include "TStyle.h"
#include "TROOT.h"
#include "TH1.h"
#include "TCanvas.h"

#include "TArtEventStore.h"
#include "TArtRawEventObject.h"

#include "TArtCalibNEBULA.h"
#include "TArtNEBULA.h"
#include "TArtNEBULAPara.h"
#include "TArtNEBULAParameters.h"

void TestNEBULA_compile()
{
  gStyle->SetOptStat(111111);

  TCanvas* canvas = TCanvas::MakeDefCanvas();

  TArtEventStore *estore = new TArtEventStore();

  TArtNEBULAParameters *setup = new TArtNEBULAParameters();
  setup->LoadParameter("db/NEBULA.xml");

  TArtCalibNEBULA *mynebula= new TArtCalibNEBULA(setup);

  TArtRawEventObject *rawevent = new TArtRawEventObject();
  estore->Initialize(rawevent); 
  estore->Open("ridf/test.ridf");

  TH1* hadc = new TH1I("hadc", "hist of adc", 4100, 0, 4100);
  TH1* htdc = new TH1I("htdc", "hist of tdc", 4100, 0, 4100);
 
  int neve = 0;
  while(estore->GetNextEvent() && neve<10000){
    std::cout << "\r AnaNEBULA: " << neve;
    mynebula->ReconstructData(rawevent);

    Int_t NumNEBULA = mynebula->GetNumNEBULA();
    for(int i=0; i < NumNEBULA; ++i){
      TArtNEBULA* pla = mynebula->GetNEBULA(i);

      hadc->Fill(pla->GetRawADC());
      htdc->Fill(pla->GetRawTDC());

//      const TArtNEBULAPara* para = pla->GetPara();
//      std::cout << "ID:" << para->GetID() << std::endl;
//      std::cout << "Name:" << para->GetDetectorName() << std::endl;
//      std::cout << "Layer:" << para->GetLayer() << std::endl;
//      std::cout << "SubLayer:" << para->GetSubLayer() << std::endl;
    }
    mynebula->ClearData();
    rawevent->Clear();
    ++neve;
  }
  std::cout << std::endl;

  canvas->Divide(1,2);
  canvas->cd(1);
  hadc->Draw();
  canvas->cd(2);
  htdc->Draw();

  return;
}
