
#include <iostream>

#include "TH1.h"
#include "TH2.h"
#include "TCanvas.h"

#include "TArtAnaLoopNEBULA.hh"

#include "TArtCalibNEBULA.hh"
#include "TArtNEBULAPla.hh"
#include "TArtNEBULAPlaPara.hh"
#include "TArtNEBULAParameters.hh"

static TArtCalibNEBULA *mynebula;
static TArtNEBULAParameters *NEBULAParameters;

static TH1 *h1id;
static TH1 *h1tu, *h1td, *h1qu, *h1qd;
static TH1 *h2idtu, *h2idtd, *h2idqu, *h2idqd;

TArtAnaLoopNEBULA::TArtAnaLoopNEBULA()
  : TArtAnaLoop()
{;}

TArtAnaLoopNEBULA::~TArtAnaLoopNEBULA()
{
  Destruct();
}

void TArtAnaLoopNEBULA::Construct()
{
  mynebula= new TArtCalibNEBULA;
  NEBULAParameters = new TArtNEBULAParameters;
  NEBULAParameters->LoadParameter("db/NEBULA.xml");

  h1id = new TH1I("h1id", "id",  150, 1,  151);
  h1tu = new TH1I("h1tu", "tu", 4100, 0, 4100);
  h1td = new TH1I("h1td", "td", 4100, 0, 4100);
  h1qu = new TH1I("h1qu", "qu", 4100, 0, 4100);
  h1qd = new TH1I("h1qd", "qd", 4100, 0, 4100);
  h2idtu = new TH2I("h2idtu", "id vs tu", 150, 1, 151, 4100, 0, 4100);
  h2idtd = new TH2I("h2idtd", "id vs td", 150, 1, 151, 4100, 0, 4100);
  h2idqu = new TH2I("h2idqu", "id vs qu", 150, 1, 151, 4100, 0, 4100);
  h2idqd = new TH2I("h2idqd", "id vs qd", 150, 1, 151, 4100, 0, 4100);
}

void TArtAnaLoopNEBULA::Calculate()
{
  mynebula->BeginEvent();
  mynebula->ReconstructData();

  Int_t NumNEBULAPla = mynebula->GetNumNEBULAPla();
  for(int i=0; i<NumNEBULAPla; ++i){
    TArtNEBULAPla* pla = mynebula->GetNEBULAPla(i);
    if(pla->GetDataState() < 0) continue;
    if(pla->GetIHitMin() < 4) continue;
    //    TArtNEBULAPlaPara* parau = mynebula->FindNEBULAPlaPara(pla->GetID(), "U");
    //    TArtNEBULAPlaPara* parad = mynebula->FindNEBULAPlaPara(pla->GetID(), "D");
    //    std::cout << *parau << std::endl;
    //    std::cout << *parad << std::endl;

    int tu = pla->GetRawTU();
    int td = pla->GetRawTD();
    int qu = pla->GetRawQU();
    int qd = pla->GetRawQD();
    int id = pla->GetID();

    if(h1id) h1id->Fill(id);
    if(h1tu) h1tu->Fill(tu);
    if(h1td) h1td->Fill(td);
    if(h1qu) h1qu->Fill(qu);
    if(h1qd) h1qd->Fill(qd);
    if(h2idtu) h2idtu->Fill(id,tu);
    if(h2idtd) h2idtd->Fill(id,td);
    if(h2idqu) h2idqu->Fill(id,qu);
    if(h2idqd) h2idqd->Fill(id,qd);
  }

  mynebula->EndEvent();
}

void TArtAnaLoopNEBULA::Destruct()
{
  delete mynebula;
  mynebula = 0;
  delete NEBULAParameters;
  NEBULAParameters = 0;

  return;
}

const char* TArtAnaLoopNEBULA::ClassName() const
{
  return "TArtAnaLoopNEBULA";
}

