#ifndef TARTSIMPLEFUNCTION_HH
#define TARTSIMPLEFUNCTION_HH

#include "TObject.h"

class TH1;
class TH1D;
class TH2;
class TH3;
class TProfile;
class TFitResult;
class TFitResultPtr;
class TGraph;

class TArtSimpleFunction
{
public:
  //  static void Watch(void (*fpt)(), UInt_t milliSec, Int_t num);

  static TH1* CreateAndFillHist(const char* name, const char* title,
				Double_t valx, Int_t nbinsx, Double_t xlow, Double_t xup);
  static TH2* CreateAndFillHist(const char* name, const char* title,
				Double_t valx, Int_t nbinsx, Double_t xlow, Double_t xup,
				Double_t valy, Int_t nbinsy, Double_t ylow, Double_t yup);
  static TH3* CreateAndFillHist(const char* name, const char* title,
				Double_t valx, Int_t nbinsx, Double_t xlow, Double_t xup,
				Double_t valy, Int_t nbinsy, Double_t ylow, Double_t yup,
				Double_t valz, Int_t nbinsz, Double_t zlow, Double_t zup);
  static TH1* CreateAndFillHist(const char* name, const char* title, Int_t size,
				Double_t* valx, Int_t nbinsx, Double_t xlow, Double_t xup);
  static TH2* CreateAndFillHist(const char* name, const char* title, Int_t size,
				Double_t* valx, Int_t nbinsx, Double_t xlow, Double_t xup,
				Double_t* valy, Int_t nbinsy, Double_t ylow, Double_t yup);
  static TH3* CreateAndFillHist(const char* name, const char* title, Int_t size,
				Double_t* valx, Int_t nbinsx, Double_t xlow, Double_t xup,
				Double_t* valy, Int_t nbinsy, Double_t ylow, Double_t yup,
				Double_t* valz, Int_t nbinsz, Double_t zlow, Double_t zup);

  static void ReadObjectFromFile(char* filename);
  static void WriteObjectToFile(char* filename);
  //write current hist to text.
  static TH1* WriteHistToText(char* filename);
  static TH1* CreateHistFromText(char* filename);
  static TGraph* CreateGraphFromText(char* filename);

  static void StatusHist();
  static void StatusX(Int_t binx1, Int_t binx2);
  static void GStatusX();

  static TH2* CutGHist();

  static TFitResultPtr Fit(const char* formula, Option_t* option = "", Option_t* goption = "", Double_t xmin = 0, Double_t xmax = 0);
  static TFitResultPtr FitPolynomial(int n = 1, Option_t* option = "", Option_t* goption = "", Double_t xmin = 0, Double_t xmax = 0);
  static TFitResultPtr FitExponential(Option_t* option = "", Option_t* goption = "", Double_t xmin = 0,  Double_t xmax = 0);
  static TFitResultPtr FitGaussian(Option_t* option = "", Option_t* goption = "", Double_t xmin = 0,  Double_t xmax = 0);
  static TFitResultPtr FitLandau(Option_t* option = "", Option_t* goption = "", Double_t xmin = 0,  Double_t xmax = 0);
  static TFitResultPtr GFitPolynomial(int n = 1, Option_t* option = "", Option_t* goption = "");
  static TFitResultPtr GFitExponential(Option_t* option = "", Option_t* goption = "");
  static TFitResultPtr GFitGaussian(Option_t* option = "", Option_t* goption = "");
  static TFitResultPtr GFitLandau(Option_t* option = "", Option_t* goption = "");

  static TH1* ChangeBin(Int_t ngroupx, Int_t ngroupy = 1, Int_t ngroupz = 1);
  
  static TProfile* ProfileX(Int_t firstybin = 1, Int_t lastybin = -1, Option_t* option = "");
  static TProfile* ProfileY(Int_t firstxbin = 1, Int_t lastxbin = -1, Option_t* option = "");
//  static TH1D* ProjectionX(Int_t firstybin = 0, Int_t lastybin = -1, Option_t* option = "");
//  static TH1D* ProjectionY(Int_t firstxbin = 0, Int_t lastxbin = -1, Option_t* option = "");
  static TH1D* ProjectionX(Option_t* option = "");
  static TH1D* ProjectionY(Option_t* option = "");
  static TH1* SliceX(Int_t num);
  static TH1* SliceY(Int_t num);
  static TH1D* BanY(double firsty, double lasty, Option_t* option = "");
  static TH1D* BanX(double firstx, double lastx, Option_t* option = "");
  static TH1* Range(double firstx = 0, double lastx = -1,
			  double firsty = 0, double lasty = -1,
			  double firstz = 0, double lastz = -1);
  static TH1* RangeX(double firstx = 0, double lastx = -1);
  static TH1* RangeY(double firsty = 0, double lasty = -1);
  static TH1* RangeZ(double firstz = 0, double lastz = -1);
  static TH1* GRange();
  static TH1* GRangeX();
  static TH1* GRangeY();
  static TH1* GRangeXY();
  static TH1* Blow(double firstx = 0, double lastx = -1,
		   double firsty = 0, double lasty = -1,
		   double firstz = 0, double lastz = -1);
  static TH1* BlowX(double firstx = 0, double lastx = -1);
  static TH1* BlowY(double firsty = 0, double lasty = -1);
  static TH1* BlowZ(double firstz = 0, double lastz = -1);
  static TH1* GBlow();
  static TH1* GBlowX();
  static TH1* GBlowY();
  static TH1* GBlowXY();

  static TH1* MinMax(double min, double max);

  static TH1* Scale(Double_t c);
  static TH1* Add(Int_t id1, Int_t id2, Double_t c1=1, Double_t c2=1);
  static TH1* Multiply(Int_t id1, Int_t id2, Double_t c1=1, Double_t c2=1);
  static TH1* Divide(Int_t id1, Int_t id2, Double_t c1=1, Double_t c2=1);

private:
  // Check whether the histograms have the same number of bins.
  static bool CheckConsistency(TH1* h1, TH1* h2);
};

#endif
