#ifndef _TARTNEBULAPLAPARA_H_
#define _TARTNEBULAPLAPARA_H_

#include "TArtMap.h"
#include "segidlist.h"

class TArtNEBULAPlaPara : public TObject
{
public:
  TArtNEBULAPlaPara(Int_t id, const TString& udlr, const TString& detname,
		    Int_t fpl, Int_t layer, Int_t sublayer, const Double_t* pos, 
		    Double_t tcal, Double_t toff, Double_t qcal, Double_t qped,
		    Int_t ignore)
    : TObject(),
      fID(id), fUDLR(udlr), fDetName(detname),
      fFPl(fpl), fLayer(layer), fSubLayer(sublayer),
      fTCal(tcal), fTOff(toff), fQCal(qcal), fQPed(qped),
      fIgnore(ignore)
  {
    for(int i=0; i<3; ++i) fPos[i] = pos[i];
  }
  ~TArtNEBULAPlaPara(){;}

  Int_t GetID() const {return fID;}
  const TString& GetUDLR() const {return fUDLR;}
  const TString& GetDetectorName() const {return fDetName;}
  Int_t GetFPl() const {return fFPl;}
  Int_t GetLayer() const {return fLayer;}
  Int_t GetSubLayer() const {return fSubLayer;}
  const Double_t* GetPos() const {return fPos;} 
  Double_t GetPos(int i) const {return fPos[i];} 
  Double_t GetTCal() const {return fTCal;} 
  Double_t GetTOffset() const {return fTOff;} 
  Double_t GetQCal() const {return fQCal;} 
  Double_t GetQPed() const {return fQPed;} 
  Int_t GetIgnore() const {return fIgnore;}

  friend ostream& operator<<(ostream& out, const TArtNEBULAPlaPara& p){
    out << "ID: " << p.fID << endl;
    out << "UDLR: " << p.fUDLR << endl;
    out << "DetectorName: " << p.fDetName << endl;
    out << "Focal Plane: " << p.fFPl << endl;
    out << "Layer: " << p.fLayer << endl;
    out << "SubLayer: " << p.fSubLayer << endl;
    out << "Position: " << p.fPos[0]<< " " << p.fPos[1]<< " " << p.fPos[2]<< endl;
    out << "T Calib: " << p.fTCal << endl;
    out << "T Offset: " << p.fTOff << endl;
    out << "Q Calib: " << p.fQCal << endl;
    out << "Q pedestal: " << p.fQPed << endl;
    out << "Ignore: " << p.fIgnore << endl;
    out << "Map of QDC: "  << p.fMapQDC << endl;
    out << "Map of TDC: "  << p.fMapTDC << endl;
    out << endl;
    return out;
  }

  void SetMapTDC(Int_t tgeo, Int_t tch)
  {
    fMapTDC.SetMap(fFPl,41,tgeo,tch); 
    //    fMapTDC.SetMap(fpl,NEBULAT,tgeo,tch); 
    //    cout << "TDC is mapped to " << fMapTDC.GetMapInfo() << " " << fMapTDC.GetName() << endl;
  }
  void SetMapQDC(Int_t qgeo, Int_t qch)
  {
    fMapQDC.SetMap(fFPl,42,qgeo,qch); 
    //    fMapQDC.SetMap(fpl,NEBULAQ,qgeo,qch); 
    //    cout << "QDC is mapped to " << fMapQDC.GetMapInfo() << " " << fMapQDC.GetName() << endl;
  }    

  const TArtRIDFMap& GetTDCMap() const {return fMapTDC;}
  const TArtRIDFMap& GetQDCMap() const {return fMapQDC;}

private:
  Int_t     fID;
  TString   fUDLR;
  TString   fDetName;
  Int_t     fFPl;
  Int_t     fLayer;
  Int_t     fSubLayer;
  Double_t  fPos[3];
  Double_t  fTCal;
  Double_t  fTOff;
  Double_t  fQCal;
  Double_t  fQPed;
  Int_t     fIgnore;

  TArtRIDFMap fMapTDC;
  TArtRIDFMap fMapQDC;

  ClassDef(TArtNEBULAPlaPara,1);
};

#endif
